RegisterField

Struct RegisterField 

pub struct RegisterField<T: RegisterType> { /* private fields */ }
Definition of a field contained inside of a register. Each field is defined by a mask and the bit shift value when constructing the field definition the stored mask is already shifted by the shift value

Implementations

Source

impl RegisterField<u8>

pub const fn new(mask: u8, shift: u8) -> RegisterField<u8>

Create a new register field definition with the mask and the shift offset for this mask. The offset is the bit offset this field begins.

pub fn mask(&self) -> u8

retrieve the current mask of the field shifted to its correct position

pub fn shift(&self) -> u8

retrieve the current shift of the field

Source

impl RegisterField<u16>

pub const fn new(mask: u16, shift: u16) -> RegisterField<u16>

Create a new register field definition with the mask and the shift offset for this mask. The offset is the bit offset this field begins.

pub fn mask(&self) -> u16

retrieve the current mask of the field shifted to its correct position

pub fn shift(&self) -> u16

retrieve the current shift of the field

Source

impl RegisterField<u32>

pub const fn new(mask: u32, shift: u32) -> RegisterField<u32>

Create a new register field definition with the mask and the shift offset for this mask. The offset is the bit offset this field begins.

pub fn mask(&self) -> u32

retrieve the current mask of the field shifted to its correct position

pub fn shift(&self) -> u32

retrieve the current shift of the field

Source

impl RegisterField<u64>

pub const fn new(mask: u64, shift: u64) -> RegisterField<u64>

Create a new register field definition with the mask and the shift offset for this mask. The offset is the bit offset this field begins.

pub fn mask(&self) -> u64

retrieve the current mask of the field shifted to its correct position

pub fn shift(&self) -> u64

retrieve the current shift of the field