RegisterFieldValue

Struct RegisterFieldValue 

pub struct RegisterFieldValue<T: RegisterType> { /* private fields */ }
Definition of a specific fieldvalue of a regiser. This structure allows to combine field values with bit operators like | and & to build the final value that should be written to a register

Implementations

Source

impl RegisterFieldValue<u8>

pub const fn new(field: RegisterField<u8>, value: u8) -> Self

Create a new fieldvalue based on the field definition and the value given

pub const fn from_raw(field: RegisterField<u8>, raw_value: u8) -> Self

Create a new fieldvalue based on the field definition and the raw value given

pub fn value(&self) -> u8

Retrieve the register field value

pub fn raw_value(&self) -> u8

Retrieve the register field raw value, means the value is returned in it’s position as it appears in the register when read with the field mask applied but not shifted

pub fn mask(&self) -> u8

Retrieve the field mask used with this register field. The mask is shifted to it’s corresponding field position

Source

impl RegisterFieldValue<u16>

pub const fn new(field: RegisterField<u16>, value: u16) -> Self

Create a new fieldvalue based on the field definition and the value given

pub const fn from_raw(field: RegisterField<u16>, raw_value: u16) -> Self

Create a new fieldvalue based on the field definition and the raw value given

pub fn value(&self) -> u16

Retrieve the register field value

pub fn raw_value(&self) -> u16

Retrieve the register field raw value, means the value is returned in it’s position as it appears in the register when read with the field mask applied but not shifted

pub fn mask(&self) -> u16

Retrieve the field mask used with this register field. The mask is shifted to it’s corresponding field position

Source

impl RegisterFieldValue<u32>

pub const fn new(field: RegisterField<u32>, value: u32) -> Self

Create a new fieldvalue based on the field definition and the value given

pub const fn from_raw(field: RegisterField<u32>, raw_value: u32) -> Self

Create a new fieldvalue based on the field definition and the raw value given

pub fn value(&self) -> u32

Retrieve the register field value

pub fn raw_value(&self) -> u32

Retrieve the register field raw value, means the value is returned in it’s position as it appears in the register when read with the field mask applied but not shifted

pub fn mask(&self) -> u32

Retrieve the field mask used with this register field. The mask is shifted to it’s corresponding field position

Source

impl RegisterFieldValue<u64>

pub const fn new(field: RegisterField<u64>, value: u64) -> Self

Create a new fieldvalue based on the field definition and the value given

pub const fn from_raw(field: RegisterField<u64>, raw_value: u64) -> Self

Create a new fieldvalue based on the field definition and the raw value given

pub fn value(&self) -> u64

Retrieve the register field value

pub fn raw_value(&self) -> u64

Retrieve the register field raw value, means the value is returned in it’s position as it appears in the register when read with the field mask applied but not shifted

pub fn mask(&self) -> u64

Retrieve the field mask used with this register field. The mask is shifted to it’s corresponding field position