pub struct RegisterFieldValue<T: RegisterType> { /* private fields */ }Expand description
Definition of a specific fieldvalue of a regiser. This structure allows to combine field values with bit operators
like | and & to build the final value that should be written to a register
Implementations
Sourceimpl RegisterFieldValue<u8>
impl RegisterFieldValue<u8>
Sourcepub const fn new(field: RegisterField<u8>, value: u8) -> Self
pub const fn new(field: RegisterField<u8>, value: u8) -> Self
Create a new fieldvalue based on the field definition and the value given
Sourcepub const fn from_raw(field: RegisterField<u8>, raw_value: u8) -> Self
pub const fn from_raw(field: RegisterField<u8>, raw_value: u8) -> Self
Create a new fieldvalue based on the field definition and the raw value given
Sourceimpl RegisterFieldValue<u16>
impl RegisterFieldValue<u16>
Sourcepub const fn new(field: RegisterField<u16>, value: u16) -> Self
pub const fn new(field: RegisterField<u16>, value: u16) -> Self
Create a new fieldvalue based on the field definition and the value given
Sourcepub const fn from_raw(field: RegisterField<u16>, raw_value: u16) -> Self
pub const fn from_raw(field: RegisterField<u16>, raw_value: u16) -> Self
Create a new fieldvalue based on the field definition and the raw value given
Sourceimpl RegisterFieldValue<u32>
impl RegisterFieldValue<u32>
Sourcepub const fn new(field: RegisterField<u32>, value: u32) -> Self
pub const fn new(field: RegisterField<u32>, value: u32) -> Self
Create a new fieldvalue based on the field definition and the value given
Sourcepub const fn from_raw(field: RegisterField<u32>, raw_value: u32) -> Self
pub const fn from_raw(field: RegisterField<u32>, raw_value: u32) -> Self
Create a new fieldvalue based on the field definition and the raw value given
Sourceimpl RegisterFieldValue<u64>
impl RegisterFieldValue<u64>
Sourcepub const fn new(field: RegisterField<u64>, value: u64) -> Self
pub const fn new(field: RegisterField<u64>, value: u64) -> Self
Create a new fieldvalue based on the field definition and the value given
Sourcepub const fn from_raw(field: RegisterField<u64>, raw_value: u64) -> Self
pub const fn from_raw(field: RegisterField<u64>, raw_value: u64) -> Self
Create a new fieldvalue based on the field definition and the raw value given